"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const winston_1 = require("winston");
const { printf } = winston_1.format;
const logFormat = printf((info) => {
    let level;
    switch (info.level) {
        case 'info':
            level = chalk_1.default.green(info.level);
            break;
        case 'warn':
            level = chalk_1.default.yellow(info.level);
            break;
        case 'debug':
            level = chalk_1.default.blue(info.level);
            break;
        case 'error':
            level = chalk_1.default.red(info.level);
            break;
        default:
            level = info.level;
    }
    if (info.type === 'validation' && Array.isArray(info.errors)) {
        const errors = [];
        for (const e of info.errors) {
            let error = `${e.property}: ${e.value}\n`;
            if (e.constraints) {
                for (const [, message] of Object.entries(e.constraints)) {
                    error += `${message}\n`;
                    errors.push(error);
                }
            }
        }
        return `[${level}]: ${info.message} \n${errors.join('\n')}`;
    }
    return `[${level}]: ${info.message}`;
});
const logger = winston_1.createLogger({
    level: process.env.DEBUG === 'nuxt-config' ? 'debug' : 'info',
    format: logFormat,
    transports: [
        new winston_1.transports.Console(),
    ],
});
exports.default = logger;
//# sourceMappingURL=logger.js.map