"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = __importDefault(require("fs-extra"));
const node_cron_1 = __importDefault(require("node-cron"));
const path_1 = __importDefault(require("path"));
const util_1 = __importDefault(require("util"));
const streamPipeline = util_1.default.promisify(require('stream').pipeline);
const node_fetch_1 = __importDefault(require("node-fetch"));
const env_manager_js_1 = __importDefault(require("@deepvision/env-manager.js"));
const envApi = new env_manager_js_1.default({
    endpoint: process.env.ENVMGR_EP,
    getAccessToken: () => {
        return process.env.SERVICE_TOKEN;
    },
});
async function download(url) {
    const response = await node_fetch_1.default(url);
    if (!response.ok) {
        throw new Error(`unexpected response ${response.statusText}`);
    }
    await streamPipeline(response.body, fs_extra_1.default.createWriteStream(path_1.default.resolve(process.cwd(), './temp/new.ico')));
}
async function SettingsSync() {
    let settings = await fs_extra_1.default.readJSON(path_1.default.resolve(process.cwd(), './settings.json'));
    await fs_extra_1.default.ensureDir(path_1.default.resolve(process.cwd(), './temp/'));
    node_cron_1.default.schedule('*/1 * * * *', async () => {
        try {
            const result = await envApi.environments.withId(process.env.ENV_ID).getSettings();
            const newSettings = result;
            if (settings.favicon !== newSettings.favicon) {
                await download(newSettings.favicon);
                await fs_extra_1.default.move(path_1.default.resolve(process.cwd(), './temp/new.ico'), path_1.default.resolve(process.cwd(), './static/favicon.ico'), { overwrite: true });
            }
            settings = newSettings;
        }
        catch (e) {
            console.log(`Can't Sync Settings`);
            console.log(e);
        }
    });
}
exports.default = SettingsSync;
;
//# sourceMappingURL=settings-sync.js.map