"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const util_1 = __importDefault(require("util"));
const streamPipeline = util_1.default.promisify(require('stream').pipeline);
const node_fetch_1 = __importDefault(require("node-fetch"));
const env_manager_js_1 = __importDefault(require("@deepvision/env-manager.js"));
const envApi = new env_manager_js_1.default({
    endpoint: process.env.ENVMGR_EP,
    getAccessToken: () => {
        return process.env.SERVICE_TOKEN;
    },
});
async function download(url) {
    const response = await node_fetch_1.default(url);
    if (!response.ok) {
        throw new Error(`unexpected response ${response.statusText}`);
    }
    await streamPipeline(response.body, fs_extra_1.default.createWriteStream(path_1.default.resolve(process.cwd(), './temp/new.ico')));
}
async function SettingsSync() {
    const settings = await fs_extra_1.default.readJSON(path_1.default.resolve(process.cwd(), './settings.json'));
    const result = await envApi.environments.withId(process.env.ENVMGR_EP).getSettings();
    const newSettings = result;
    console.log(process.cwd());
    await fs_extra_1.default.ensureDir(path_1.default.resolve(process.cwd(), './temp/'));
    if (settings.favicon !== newSettings.favicon) {
        await download(settings.favicon);
        await fs_extra_1.default.move(path_1.default.resolve(process.cwd(), './temp/new.ico'), path_1.default.resolve(process.cwd(), './static/favicon.ico'));
    }
    else {
        await fs_extra_1.default.copy(path_1.default.resolve(__dirname, './favicon.ico'), path_1.default.resolve(__dirname, '../../static/favicon.ico'));
    }
}
exports.default = SettingsSync;
;
//# sourceMappingURL=settings.js.map