"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = __importDefault(require("../logger"));
const class_validator_1 = require("class-validator");
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const env_manager_js_1 = __importDefault(require("@deepvision/env-manager.js"));
class CVFetchOptions {
}
__decorate([
    class_validator_1.IsString(),
    class_validator_1.IsIn(['environment', 'service'], { message: 'Type must be "environment" or "service"' }),
    __metadata("design:type", String)
], CVFetchOptions.prototype, "type", void 0);
class FetchService {
    constructor(options) {
        this.options = new CVFetchOptions();
        for (const [key, value] of Object.entries(options)) {
            this.options[key] = value;
        }
    }
    async validate() {
        const errors = await class_validator_1.validate(this.options);
        if (errors.length > 0) {
            logger_1.default.error('Invalid options', {
                errors,
                type: 'validation',
            });
            return false;
        }
        return true;
    }
    async fetch() {
        const isValid = await this.validate();
        if (!isValid) {
            logger_1.default.error('Invalid options');
        }
        const settings = await this.getSettings();
        await fs_extra_1.default.writeFile(path_1.default.resolve(process.cwd(), './settings.json'), JSON.stringify(settings, null, 2));
        logger_1.default.info('Settings has been fetched');
    }
    async getSettings() {
        const { ENV_ID, NETWORK_ID, SERVICE_ID, ENVMGR_EP, SERVICE_TOKEN, } = process.env;
        if (!NETWORK_ID) {
            logger_1.default.error('Network ID is not found in process.env.NETWORK_ID');
        }
        if (this.options.type === 'environment') {
            if (!ENV_ID) {
                logger_1.default.error('Environment ID is not found in process.env.ENV_ID');
            }
            if (!SERVICE_TOKEN) {
                logger_1.default.error('Service Token is not found in process.env.SERVICE_TOKEN');
            }
            const envApi = new env_manager_js_1.default({
                endpoint: ENVMGR_EP,
                getAccessToken: () => {
                    return SERVICE_TOKEN;
                },
            });
            logger_1.default.info(`TYPE: ENVIRONMENT ID: ${ENV_ID}; NETWORK_ID: ${NETWORK_ID}`);
            const settings = await envApi.environments.withId(ENV_ID).getSettings();
            return settings;
        }
        if (!SERVICE_ID) {
            logger_1.default.error('Service type is not found in process.env.SERVICE_ID');
        }
        logger_1.default.info(`TYPE: SERVICE; SERVICE_ID: ${SERVICE_ID}; NETWORK: ${NETWORK_ID}`);
        const settingsPath = path_1.default.resolve(process.cwd(), `./.settings/${SERVICE_ID}.${NETWORK_ID}.json`);
        const isSettingsExists = await fs_extra_1.default.exists(settingsPath);
        if (!isSettingsExists) {
            logger_1.default.error('settings not found');
        }
        const settings = await fs_extra_1.default.readJSON(settingsPath);
        return settings;
    }
}
exports.FetchService = FetchService;
//# sourceMappingURL=fetch-service.js.map